@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.70 2004/02/18 16:22:18 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.76 2004/05/21 16:20:49 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -21,7 +21,7 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <malloc.h>
+#include <stdlib.h>
 #include <sys/types.h>
 #include "calctool.h"
 #include <gdk/gdkkeysyms.h>
@@ -171,8 +171,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("/"),
     N_("Divide"),
     NULL,
-    { 0,         0,             0,      GDK_SHIFT_MASK, 0 },
-    { GDK_slash, GDK_KP_Divide, GDK_R5, GDK_slash,      0 },
+    { 0,         GDK_SHIFT_MASK, 0,             0,      GDK_SHIFT_MASK, 0 },
+    { GDK_slash, GDK_slash,      GDK_KP_Divide, GDK_R5, GDK_slash,      0 },
     '/',
     M_NONE,
     do_calc
@@ -188,7 +188,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     do_none
 },
 {
-    N_("Bsp"),
+    N_("Bksp"),
     N_("Remove rightmost character from displayed value"),
     N_("Backspace"),
     { 0, 0 },
@@ -935,8 +935,8 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },
 {
     N_("Or"),
-    N_("Logical OR"),
-    "logical OR",
+    N_("Bitwise OR"),
+    "bitwise OR",
     { GDK_SHIFT_MASK, 0 },
     { GDK_bar, 0 },
     '|',
@@ -945,7 +945,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },
 {
     N_("And"),
-    N_("Logical AND"),
+    N_("Bitwise AND"),
     NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_ampersand, 0 },
@@ -955,7 +955,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },       
 {        
     N_("Not"),
-    N_("Logical NOT"),
+    N_("Bitwise NOT"),
     NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_asciitilde, 0 },
@@ -965,7 +965,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },
 {
     N_("Xor"),
-    N_("Logical XOR"),
+    N_("Bitwise XOR"),
     NULL,
     { GDK_SHIFT_MASK, GDK_SHIFT_MASK,  0 },
     { GDK_caret,      GDK_asciicircum, 0 },
@@ -975,7 +975,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },
 {
     N_("Xnor"),
-    N_("Logical XNOR"),
+    N_("Bitwise XNOR"),
     NULL,
     { 0, 0 },
     { GDK_n, 0 },
@@ -1066,7 +1066,7 @@ doerr(char *errmes)
         return;
     }
     STRCPY(v->display, errmes);
-    set_display(v->display);
+    set_display(v->display, FALSE);
     set_error_state(TRUE);
     beep();
 }
@@ -1075,16 +1075,16 @@ doerr(char *errmes)
 static void
 init_text()         /* Setup constant strings. */
 {
-    STRCPY(v->con_names[0], _("kilometers per hour or miles per hour"));
+    STRCPY(v->con_names[0], _("Kilometer-to-mile conversion factor"));
     STRCPY(v->con_names[1], _("square root of 2"));
     STRCPY(v->con_names[2], _("e"));
     STRCPY(v->con_names[3], _("pi"));
-    STRCPY(v->con_names[4], _("centimeters or inches"));
+    STRCPY(v->con_names[4], _("Centimeter-to-inch conversion factor"));
     STRCPY(v->con_names[5], _("degrees in a radian"));
     STRCPY(v->con_names[6], _("2 ^ 20"));
-    STRCPY(v->con_names[7], _("grams or ounces"));
-    STRCPY(v->con_names[8], _("kilojoules or British thermal units"));
-    STRCPY(v->con_names[9], _("cubic centimeters or cubic inches"));
+    STRCPY(v->con_names[7], _("Gram-to-ounce conversion factor"));
+    STRCPY(v->con_names[8], _("Kilojoule-to-British-thermal-unit conversion factor"));
+    STRCPY(v->con_names[9], _("Cubic-centimeter-to-cubic-inch conversion factor"));
 }
 
 
