@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.44 2004/02/27 15:46:03 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.46 2004/05/17 17:41:44 padraigo Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -37,7 +37,7 @@ localize_number(char *dest, const char *src)
 {
     char tnum[MAX_LOCALIZED], *dstp;
 
-    if (v->show_tsep && v->base == DEC) {
+    if (!v->error && v->show_tsep && v->base == DEC) {
 	const char *radixp, *srcp;
 	int n, i;
 	size_t tsep_len;
@@ -114,7 +114,7 @@ clear_display(int initialise)
     i = 0;
     mpcim(&i, v->MPdisp_val);
     STRCPY(v->display, make_number(v->MPdisp_val, v->base, FALSE, FALSE));
-    set_display(v->display);
+    set_display(v->display, FALSE);
 
     if (initialise == TRUE) {
         v->show_paren = 0;
@@ -503,7 +503,7 @@ paren_disp(char c)
 
     n = (n < MAX_DIGITS) ? 0 : n - MAX_DIGITS;
     v->show_paren = 1;       /* Hack to get set_display to really display it. */
-    set_display(&v->display[n]);
+    set_display(&v->display[n], FALSE);
     v->show_paren = 0;
 }
 
@@ -562,6 +562,6 @@ show_display(int *MPval)
 {
     if (!v->error) {
         STRCPY(v->display, make_number(MPval, v->base, TRUE, FALSE));
-        set_display(v->display);
+        set_display(v->display, FALSE);
     }
 }
