@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.116 2004/02/27 22:15:01 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.123 2004/06/01 22:38:07 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -56,12 +56,12 @@
 #define BUT_E     X->sci_buttons[17]       /* e */
 #define BUT_F     X->sci_buttons[18]       /* f */
 
-typedef struct Xobject {               /* Gtk+/Xlib graphics object. */
+struct Xobject {               /* Gtk+/Xlib graphics object. */
     GtkAccelGroup *kbd_accel;
     GdkAtom clipboard_atom;
     GConfClient *client;
-    GtkItemFactory *mb_fact;           /* Menubar item factory. */
-    GtkItemFactory *fact[MAXMENUS];
+    GtkUIManager *ui;
+    GtkActionGroup *actions;
     GtkTooltips *tips;
     GtkWidget *aframe;                 /* ASCII window. */
     GtkWidget *aframe_ch;
@@ -94,8 +94,9 @@ typedef struct Xobject {               /* Gtk+/Xlib graphics object. */
     Display *dpy;
 
     int menuval;                  /* Index to button array at menu time. */
+    char *lnp;                    /* Localized numerical point (UTF8 format) */
     struct button *mrec[MAXMENUS];
-} XObject;
+};
 
 typedef struct Xobject *XVars;
 
@@ -121,6 +122,7 @@ static GtkWidget *make_menu_button(gchar *, int);
 static GtkWidget *make_but_panel(GtkWidget *, GtkWidget **,
                                  struct button *, int, int, char *);
 
+static char *get_localized_numeric_point(void);
 static char *make_hostname(Display *);
 
 static gboolean aframe_key_cb(GtkWidget *, GdkEventKey *, gpointer);
@@ -132,20 +134,22 @@ static void about_cb(GtkWidget *, gpointer);
 static void add_cf_column(GtkTreeView *, gchar *, gint, gboolean);
 static void aframe_cancel_cb(GtkButton *, gpointer);
 static void aframe_ok_cb(GtkButton *, gpointer);
-static void astz_proc(gpointer, int, GtkWidget *);
+static void astz_proc(GtkAction *action);
 static void base_cb(GtkToggleButton *, gpointer);
 static void cell_edited(GtkCellRendererText *, 
                         const gchar *, const gchar *, gpointer);
 static void create_con_fun_menu(enum menu_type);
 static void create_menu_item_with_markup(char *, int, int);
+static void die_cb(GnomeClient *client, gpointer data);
 static void disp_cb(GtkToggleButton *, gpointer);
 static void hyp_cb(GtkToggleButton *, gpointer);
 static void inv_cb(GtkToggleButton *, gpointer);
-static void mb_proc(gpointer, int, GtkWidget *);
+static void mb_proc(GtkAction *action);
+static void mb_acc_radio_proc(GtkAction *action, GtkRadioAction *current);
+static void mb_base_radio_proc(GtkAction *action, GtkRadioAction *current);
 static void menu_pos_func(GtkMenu *, gint *, gint *, gboolean *, gpointer);
 static void menu_proc_cb(GtkMenuItem *, gpointer);
-static void menu_proc(gpointer, int, GtkWidget *);
-static void mstz_proc(gpointer, int, GtkWidget *);
+static void mstz_proc(GtkAction *action);
 static void new_cf_value(GtkMenuItem *, gpointer);
 static void put_constant(int, char *, char *);
 static void put_function(int, char *, char *);
@@ -157,87 +161,221 @@ static void set_memory_toggle(int);
 static void set_show_tsep_toggle(int);
 static void set_show_zeroes_toggle(int);
 static void trig_cb(GtkToggleButton *, gpointer);
-static void ts_proc(gpointer, int, GtkWidget *);
+static void ts_proc(GtkAction *action);
 
 static XVars X;
 
 /* Menubar menus. */
 
-static GtkItemFactoryEntry main_menu[] = {
-    { N_("/_Calculator"),          NULL, NULL,    0,       "<Branch>" },
-    { N_("/Calculator/_Quit"), "<control>Q", mb_proc, M_QUIT,  "<StockItem>" , GTK_STOCK_QUIT },
+static GtkActionEntry entries[] = {
+    { "CalculatorMenu", NULL, "_Calculator" },
+    { "EditMenu",       NULL, "_Edit" },
+    { "ViewMenu",       NULL, "_View" },
+    { "HelpMenu",       NULL, "_Help" },
 
-    { N_("/_Edit"),                NULL, NULL,    0,       "<Branch>" },
-    { N_("/Edit/_Copy"),           NULL, mb_proc, M_COPY,  "<StockItem>", GTK_STOCK_COPY },
-    { N_("/Edit/_Paste"),          NULL, mb_proc, M_PASTE, "<StockItem>", GTK_STOCK_PASTE },
-    { N_("/Edit/sep1"),            NULL, NULL,    0,       "<Separator>" },
-    { N_("/Edit/_Insert ASCII Value..."), "<control>I", mb_proc, M_ASCII, NULL },
+    { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
+      N_("Quit the calculator"), G_CALLBACK(mb_proc) },
 
-    { N_("/_View"),                NULL, NULL,    0,       "<Branch>" },
-    { N_("/View/_Basic Mode"),     "<control>B", mb_proc, M_BASIC, "<RadioItem>" },
-    { N_("/View/_Financial Mode"), "<control>F", mb_proc, M_FIN, "/View/Basic Mode" },
-    { N_("/View/_Scientific Mode"),"<control>S", mb_proc, M_SCI, "/View/Basic Mode" },
-    { N_("/View/sep1"),            NULL, NULL,    0,       "<Separator>" },
-    { N_("/View/Show _Trailing Zeroes"),"<control>T", mstz_proc, M_ZEROES, "<ToggleItem>" },
-   { N_("/View/Show T_housands Separator"),"<control>K", ts_proc, M_TSEP, "<ToggleItem>" },
-    { N_("/View/sep2"),	           NULL, NULL,	  0,       "<Separator>" },
-    { N_("/View/_Memory Registers"),"<control>M", mb_proc, M_REGS, "<ToggleItem>" },
+    { "Copy", GTK_STOCK_COPY, N_("_Copy"), NULL,
+      N_("Copy selection"), G_CALLBACK(mb_proc) },
+    { "Paste", GTK_STOCK_PASTE, N_("_Paste"), NULL,
+      N_("Paste selection"), G_CALLBACK(mb_proc) },
+    { "Insert", NULL, N_("_Insert ASCII Value..."), "<control>I",
+      N_("Insert ASCII value"), G_CALLBACK(mb_proc) },
 
-    { N_("/_Help"),                NULL, NULL,    0,       "<Branch>" },
-    { N_("/Help/_Contents"),       "F1", mb_proc, M_CONTENTS, "<StockItem>", GTK_STOCK_HELP },
-    { N_("/Help/_About"),    	   NULL, about_cb, M_ABOUT, "<StockItem>", GNOME_STOCK_ABOUT },
+    { "Contents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+      N_("Show help contents"), G_CALLBACK(mb_proc) },
+    { "About", GNOME_STOCK_ABOUT, N_("_About"), NULL,
+      N_("Show about help"), G_CALLBACK(mb_proc) },
+
+    { "LSPlaces1",  NULL, N_("1 place"),   NULL, 
+      N_("1 place"),   G_CALLBACK(mb_proc) },
+    { "LSPlaces2",  NULL, N_("2 places"),  NULL, 
+      N_("2 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces3",  NULL, N_("3 places"),  NULL, 
+      N_("3 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces4",  NULL, N_("4 places"),  NULL, 
+      N_("4 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces5",  NULL, N_("5 places"),  NULL, 
+      N_("5 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces6",  NULL, N_("6 places"),  NULL, 
+      N_("6 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces7",  NULL, N_("7 places"),  NULL, 
+      N_("7 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces8",  NULL, N_("8 places"),  NULL, 
+      N_("8 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces9",  NULL, N_("9 places"),  NULL, 
+      N_("9 places"),  G_CALLBACK(mb_proc) },
+    { "LSPlaces10", NULL, N_("10 places"), NULL, 
+      N_("10 places"), G_CALLBACK(mb_proc) },
+    { "LSPlaces11", NULL, N_("11 places"), NULL, 
+      N_("11 places"), G_CALLBACK(mb_proc) },
+    { "LSPlaces12", NULL, N_("12 places"), NULL, 
+      N_("12 places"), G_CALLBACK(mb_proc) },
+    { "LSPlaces13", NULL, N_("13 places"), NULL, 
+      N_("13 places"), G_CALLBACK(mb_proc) },
+    { "LSPlaces14", NULL, N_("14 places"), NULL, 
+      N_("14 places"), G_CALLBACK(mb_proc) },
+    { "LSPlaces15", NULL, N_("15 places"), NULL, 
+      N_("15 places"), G_CALLBACK(mb_proc) },
+
+    { "RSPlaces1",  NULL, N_("1 place"),   NULL, 
+      N_("1 place"),   G_CALLBACK(mb_proc) },
+    { "RSPlaces2",  NULL, N_("2 places"),  NULL, 
+      N_("2 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces3",  NULL, N_("3 places"),  NULL, 
+      N_("3 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces4",  NULL, N_("4 places"),  NULL, 
+      N_("4 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces5",  NULL, N_("5 places"),  NULL, 
+      N_("5 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces6",  NULL, N_("6 places"),  NULL, 
+      N_("6 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces7",  NULL, N_("7 places"),  NULL, 
+      N_("7 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces8",  NULL, N_("8 places"),  NULL, 
+      N_("8 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces9",  NULL, N_("9 places"),  NULL, 
+      N_("9 places"),  G_CALLBACK(mb_proc) },
+    { "RSPlaces10", NULL, N_("10 places"), NULL, 
+      N_("10 places"), G_CALLBACK(mb_proc) },
+    { "RSPlaces11", NULL, N_("11 places"), NULL, 
+      N_("11 places"), G_CALLBACK(mb_proc) },
+    { "RSPlaces12", NULL, N_("12 places"), NULL, 
+      N_("12 places"), G_CALLBACK(mb_proc) },
+    { "RSPlaces13", NULL, N_("13 places"), NULL, 
+      N_("13 places"), G_CALLBACK(mb_proc) },
+    { "RSPlaces14", NULL, N_("14 places"), NULL, 
+      N_("14 places"), G_CALLBACK(mb_proc) },
+    { "RSPlaces15", NULL, N_("15 places"), NULL, 
+      N_("15 places"), G_CALLBACK(mb_proc) },
 };
+static guint n_entries = G_N_ELEMENTS(entries);
 
-static GtkItemFactoryEntry acc_menu[] = {
-    { N_("/0 significant places"), NULL, menu_proc, '0', "<RadioItem>" },
-    { N_("/1 significant place"), NULL, menu_proc, '1', "/0 significant places" },
-    { N_("/2 significant places"), NULL, menu_proc, '2', "/0 significant places" },
-    { N_("/3 significant places"), NULL, menu_proc, '3', "/0 significant places" },
-    { N_("/4 significant places"), NULL, menu_proc, '4', "/0 significant places" },
-    { N_("/5 significant places"), NULL, menu_proc, '5', "/0 significant places" },
-    { N_("/6 significant places"), NULL, menu_proc, '6', "/0 significant places" },
-    { N_("/7 significant places"), NULL, menu_proc, '7', "/0 significant places" },
-    { N_("/8 significant places"), NULL, menu_proc, '8', "/0 significant places" },
-    { N_("/9 significant places"), NULL, menu_proc, '9', "/0 significant places" },
-    { N_("/sep1"),           NULL, NULL,       0,  "<Separator>" },
-    { N_("/Show _Trailing Zeroes"),"<control>T", astz_proc, 'T', "<ToggleItem>" },
-};
+static GtkToggleActionEntry toggle_entries[] = {
+    { "Trailing",  NULL, N_("Show _Trailing Zeroes"),     "<control>T",
+      N_("Show trailing zeroes"),     G_CALLBACK(mstz_proc), FALSE },
+    { "Thousands", NULL, N_("Show T_housands Separator"), "<control>K",
+      N_("Show thousands separator"), G_CALLBACK(ts_proc),   FALSE },
+    { "Memory",    NULL, N_("_Memory Registers"),         "<control>M",
+      N_("Show memory registers"),    G_CALLBACK(mb_proc),   FALSE },
 
-static GtkItemFactoryEntry lshift_menu[] = {
-    { N_("/1 place"),   NULL, menu_proc, '1', NULL },
-    { N_("/2 places"),  NULL, menu_proc, '2', NULL },
-    { N_("/3 places"),  NULL, menu_proc, '3', NULL },
-    { N_("/4 places"),  NULL, menu_proc, '4', NULL },
-    { N_("/5 places"),  NULL, menu_proc, '5', NULL },
-    { N_("/6 places"),  NULL, menu_proc, '6', NULL },
-    { N_("/7 places"),  NULL, menu_proc, '7', NULL },
-    { N_("/8 places"),  NULL, menu_proc, '8', NULL },
-    { N_("/9 places"),  NULL, menu_proc, '9', NULL },
-    { N_("/10 places"), NULL, menu_proc, 'A', NULL },
-    { N_("/11 places"), NULL, menu_proc, 'B', NULL },
-    { N_("/12 places"), NULL, menu_proc, 'C', NULL },
-    { N_("/13 places"), NULL, menu_proc, 'D', NULL },
-    { N_("/14 places"), NULL, menu_proc, 'E', NULL },
-    { N_("/15 places"), NULL, menu_proc, 'F', NULL },
+    { "Show",      NULL, N_("Show _Trailing Zeroes"),     "<control>T",
+      N_("Show trailing zeroes"),     G_CALLBACK(astz_proc), FALSE },
 };
+static guint n_toggle_entries = G_N_ELEMENTS(toggle_entries);
 
-static GtkItemFactoryEntry rshift_menu[] = {
-    { N_("/1 place"),   NULL, menu_proc, '1', NULL },
-    { N_("/2 places"),  NULL, menu_proc, '2', NULL },
-    { N_("/3 places"),  NULL, menu_proc, '3', NULL },
-    { N_("/4 places"),  NULL, menu_proc, '4', NULL },
-    { N_("/5 places"),  NULL, menu_proc, '5', NULL },
-    { N_("/6 places"),  NULL, menu_proc, '6', NULL },
-    { N_("/7 places"),  NULL, menu_proc, '7', NULL },
-    { N_("/8 places"),  NULL, menu_proc, '8', NULL },
-    { N_("/9 places"),  NULL, menu_proc, '9', NULL },
-    { N_("/10 places"), NULL, menu_proc, 'A', NULL },
-    { N_("/11 places"), NULL, menu_proc, 'B', NULL },
-    { N_("/12 places"), NULL, menu_proc, 'C', NULL },
-    { N_("/13 places"), NULL, menu_proc, 'D', NULL },
-    { N_("/14 places"), NULL, menu_proc, 'E', NULL },
-    { N_("/15 places"), NULL, menu_proc, 'F', NULL },
+static GtkRadioActionEntry acc_radio_entries[] = {
+  { "SP0", NULL, N_("0 significant places"), NULL, 
+    N_("0 significant places"), '0' },
+  { "SP1", NULL, N_("1 significant place"),  NULL, 
+    N_("1 significant place"),  '1' },
+  { "SP2", NULL, N_("2 significant places"), NULL,
+    N_("2 significant places"), '2' },
+  { "SP3", NULL, N_("3 significant places"), NULL,
+    N_("3 significant places"), '3' },
+  { "SP4", NULL, N_("4 significant places"), NULL,
+    N_("4 significant places"), '4' },
+  { "SP5", NULL, N_("5 significant places"), NULL,
+    N_("5 significant places"), '5' },
+  { "SP6", NULL, N_("6 significant places"), NULL,
+    N_("6 significant places"), '6' },
+  { "SP7", NULL, N_("7 significant places"), NULL,
+    N_("7 significant places"), '7' },
+  { "SP8", NULL, N_("8 significant places"), NULL,
+    N_("8 significant places"), '8' },
+  { "SP9", NULL, N_("9 significant places"), NULL,
+    N_("9 significant places"), '9' },
 };
+static guint n_acc_radio_entries = G_N_ELEMENTS(acc_radio_entries);
+
+static GtkRadioActionEntry base_radio_entries[] = {
+  { "Basic",	  NULL, N_("_Basic mode"),	"<control>B",
+    N_("Basic mode"),	   M_BASIC },
+  { "Financial",  NULL, N_("_Financial mode"),	"<control>F",
+    N_("Financial mode"),  M_FIN },
+  { "Scientific", NULL, N_("_Scientific mode"), "<control>S",
+    N_("Scientific mode"), M_SCI },
+};
+static guint n_base_radio_entries = G_N_ELEMENTS(base_radio_entries);
+
+
+static const gchar *ui_info =
+"<ui>"
+"  <menubar name='MenuBar'>"
+"    <menu action='CalculatorMenu'>"
+"      <menuitem action='Quit'/>"
+"    </menu>"
+"    <menu action='EditMenu'>"
+"      <menuitem action='Copy'/>"
+"      <menuitem action='Paste'/>"
+"      <separator/>"
+"      <menuitem action='Insert'/>"
+"    </menu>"
+"    <menu action='ViewMenu'>"
+"      <menuitem action='Basic'/>"
+"      <menuitem action='Financial'/>"
+"      <menuitem action='Scientific'/>"
+"      <separator/>"
+"      <menuitem action='Trailing'/>"
+"      <menuitem action='Thousands'/>"
+"      <separator/>"
+"      <menuitem action='Memory'/>"
+"    </menu>"
+"    <menu action='HelpMenu'>"
+"      <menuitem action='Contents'/>"
+"      <menuitem action='About'/>"
+"    </menu>"
+"  </menubar>"
+"  <popup name='AccMenu'>"
+"    <menuitem action='SP0'/>"
+"    <menuitem action='SP1'/>"
+"    <menuitem action='SP2'/>"
+"    <menuitem action='SP3'/>"
+"    <menuitem action='SP4'/>"
+"    <menuitem action='SP5'/>"
+"    <menuitem action='SP6'/>"
+"    <menuitem action='SP7'/>"
+"    <menuitem action='SP8'/>"
+"    <menuitem action='SP9'/>"
+"    <separator/>"
+"    <menuitem action='Show'/>"
+"  </popup>"
+"  <popup name='LeftShiftMenu'>"
+"    <menuitem action='LSPlaces1'/>"
+"    <menuitem action='LSPlaces2'/>"
+"    <menuitem action='LSPlaces3'/>"
+"    <menuitem action='LSPlaces4'/>"
+"    <menuitem action='LSPlaces5'/>"
+"    <menuitem action='LSPlaces6'/>"
+"    <menuitem action='LSPlaces7'/>"
+"    <menuitem action='LSPlaces8'/>"
+"    <menuitem action='LSPlaces9'/>"
+"    <menuitem action='LSPlaces10'/>"
+"    <menuitem action='LSPlaces11'/>"
+"    <menuitem action='LSPlaces12'/>"
+"    <menuitem action='LSPlaces13'/>"
+"    <menuitem action='LSPlaces14'/>"
+"    <menuitem action='LSPlaces15'/>"
+"  </popup>"
+"  <popup name='RightShiftMenu'>"
+"    <menuitem action='RSPlaces1'/>"
+"    <menuitem action='RSPlaces2'/>"
+"    <menuitem action='RSPlaces3'/>"
+"    <menuitem action='RSPlaces4'/>"
+"    <menuitem action='RSPlaces5'/>"
+"    <menuitem action='RSPlaces6'/>"
+"    <menuitem action='RSPlaces7'/>"
+"    <menuitem action='RSPlaces8'/>"
+"    <menuitem action='RSPlaces9'/>"
+"    <menuitem action='RSPlaces10'/>"
+"    <menuitem action='RSPlaces11'/>"
+"    <menuitem action='RSPlaces12'/>"
+"    <menuitem action='RSPlaces13'/>"
+"    <menuitem action='RSPlaces14'/>"
+"    <menuitem action='RSPlaces15'/>"
+"  </popup>"
+"</ui>";
 
 
 int
@@ -245,9 +383,10 @@ main(int argc, char **argv)
 {
     char name[MAXLINE];          /* Full name of users .gcalctoolrc file. */
     struct passwd *entry;
+    GnomeClient  *client;
 
-    v = (Vars)  LINT_CAST(calloc(1, sizeof(CalcVars)));
-    X = (XVars) LINT_CAST(calloc(1, sizeof(XObject)));
+    v = (Vars)  LINT_CAST(calloc(1, sizeof(struct calcVars)));
+    X = (XVars) LINT_CAST(calloc(1, sizeof(struct Xobject)));
 
     bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
@@ -256,6 +395,12 @@ main(int argc, char **argv)
     gnome_program_init("gcalctool", VERSION, LIBGNOMEUI_MODULE, argc, argv,
                         NULL, NULL, NULL);
 
+    X->lnp = get_localized_numeric_point();
+
+    /* Connect to the die signal. */
+    client = gnome_master_client();
+    g_signal_connect(client, "die", G_CALLBACK(die_cb), NULL);
+
     gtk_rc_get_default_files();
     if ((v->home = getenv("HOME")) == NULL) {
         if ((entry = getpwuid(getuid())) != NULL) {
@@ -376,14 +521,14 @@ aframe_ok_cb(GtkButton *button, gpointer user_data)
 
 
 static void
-astz_proc(gpointer data, int choice, GtkWidget *item)
+astz_proc(GtkAction *action)
 {
     GtkWidget *mi;
 
     if (!v->doing_mi) {
         v->show_zeroes = !v->show_zeroes;
         v->doing_mi = 1;
-        mi = gtk_item_factory_get_widget_by_action(X->mb_fact, M_ZEROES);
+        mi = gtk_ui_manager_get_widget(X->ui, "/MenuBar/ViewMenu/Trailing");
         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi), v->show_zeroes);
         v->doing_mi = 0;
 
@@ -471,7 +616,7 @@ button_proc(GtkButton *widget, gpointer user_data)
 
     if (v->new_input && v->dtype == FIX) {
         STRCPY(v->fnum, v->display);
-        set_display(v->fnum);
+        set_display(v->fnum, FALSE);
     }
 }
 
@@ -780,18 +925,12 @@ create_cfframe(enum menu_type mtype, GtkWidget *dialog)
 }
 
 
-static char *
-item_factory_translate_func(const char *path, gpointer func_data)
-{
-    return(_(path));
-}
-
-
 void
 create_kframe()
 {
     char *hn;
     int count;
+    GError *error;
     GtkWidget *event_box, *view_widget;
     GtkTextBuffer *buffer;
 
@@ -818,16 +957,31 @@ create_kframe()
     gtk_container_add(GTK_CONTAINER(X->kframe), X->kvbox);
     gtk_widget_show(X->kvbox);
 
-    /* Make menubar from item factory. */
+    X->actions = gtk_action_group_new("Actions");
+    gtk_action_group_add_actions(X->actions, entries, n_entries, NULL);
+    gtk_action_group_add_toggle_actions(X->actions,
+                                        toggle_entries, n_toggle_entries,
+                                        NULL);
+    gtk_action_group_add_radio_actions(X->actions,
+                                       acc_radio_entries, n_acc_radio_entries,
+                                       -1, G_CALLBACK(mb_acc_radio_proc),
+                                       NULL);
+    gtk_action_group_add_radio_actions(X->actions,
+                                       base_radio_entries, n_base_radio_entries,
+                                       M_BASIC, G_CALLBACK(mb_base_radio_proc),
+                                       NULL);
 
-    count = sizeof(main_menu) / sizeof(main_menu[0]);
-    X->mb_fact = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", 
-                                      X->kbd_accel);
-    gtk_item_factory_set_translate_func(X->mb_fact,
-                                        item_factory_translate_func,
-                                        NULL, NULL);
-    gtk_item_factory_create_items(X->mb_fact, count, main_menu, NULL);
-    X->menubar = gtk_item_factory_get_widget(X->mb_fact, "<main>");
+    X->ui = gtk_ui_manager_new();
+    gtk_ui_manager_insert_action_group(X->ui, X->actions, 0);
+    gtk_window_add_accel_group(GTK_WINDOW(X->kframe),
+                               gtk_ui_manager_get_accel_group(X->ui));
+
+    if (!gtk_ui_manager_add_ui_from_string(X->ui, ui_info, -1, &error)) {
+        g_message("Building menus failed: %s", error->message);
+        g_error_free(error);
+    }
+
+    X->menubar = gtk_ui_manager_get_widget(X->ui, "/MenuBar"),
     gtk_widget_show(X->menubar);
     gtk_box_pack_start(GTK_BOX(X->kvbox), X->menubar, FALSE, FALSE, 0);
 
@@ -850,7 +1004,8 @@ create_kframe()
     gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(X->display_item), 12);
     gtk_text_view_set_right_margin(GTK_TEXT_VIEW(X->display_item), 6);
 
-    set_display("0.00");
+    atk_object_set_role (gtk_widget_get_accessible (X->display_item), ATK_ROLE_EDITBAR);
+    set_display("0.00", FALSE);
     gtk_widget_ref(X->display_item);
     gtk_container_set_border_width(GTK_CONTAINER(X->display_item), 2);
     gtk_container_add(GTK_CONTAINER(event_box), X->display_item);
@@ -886,13 +1041,16 @@ create_kframe()
 
     switch (v->modetype) {
         case FINANCIAL:
-            view_widget = gtk_item_factory_get_widget_by_action(X->mb_fact, M_FIN);
+            view_widget = gtk_ui_manager_get_widget(X->ui, 
+                                              "/MenuBar/ViewMenu/Financial");
             break;
         case SCIENTIFIC:
-            view_widget = gtk_item_factory_get_widget_by_action(X->mb_fact, M_SCI);
+            view_widget = gtk_ui_manager_get_widget(X->ui, 
+                                              "/MenuBar/ViewMenu/Scientific");
             break;
         default:
-            view_widget = gtk_item_factory_get_widget_by_action(X->mb_fact, M_BASIC);
+            view_widget = gtk_ui_manager_get_widget(X->ui, 
+                                              "/MenuBar/ViewMenu/Basic");
             break;
     }
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(view_widget), TRUE);
@@ -1062,6 +1220,12 @@ create_rframe()
 }
 
 
+static void
+die_cb(GnomeClient *client, gpointer data)
+{
+    gtk_main_quit();
+}
+
 
 /*ARGSUSED*/
 static gboolean
@@ -1221,18 +1385,30 @@ get_function(int n)
 }
 
 
+static char *
+get_localized_numeric_point(void)
+{
+    struct lconv *locale_data;
+    const char *decimal_point;
+    int decimal_point_len;
+
+    decimal_point = localeconv()->decimal_point;
+    decimal_point_len = strlen(decimal_point);
+
+    return(g_locale_to_utf8(decimal_point, -1, NULL, NULL, NULL));
+}
+
+
 int
 get_menu_entry(enum menu_type mtype, int offset)
 {
     switch (mtype) {
         case M_ACC :
-            return(acc_menu[offset].callback_action);
+            return(offset + '0');
 
         case M_LSHF :
-            return(lshift_menu[offset].callback_action);
-
         case M_RSHF :
-            return(rshift_menu[offset].callback_action);
+            return((offset < 10) ? offset + '0' : offset + 'A' - 10);
 
         default:
             fprintf(stderr, "need to handle menu type %d\n", mtype);
@@ -1322,6 +1498,21 @@ inv_cb(GtkToggleButton *button, gpointer user_data)
 }
 
 
+static gboolean
+check_for_localized_numeric_point(int keyval)
+{
+    gchar outbuf[10];        /* Minumum size 6. */
+    gunichar ch;
+
+    ch = gdk_keyval_to_unicode(keyval);
+    g_return_if_fail(g_unichar_validate(ch));
+
+    outbuf[g_unichar_to_utf8(ch, outbuf)] = '\0';
+
+    return(strcmp(outbuf, X->lnp) == 0);
+}
+
+
 static int
 check_vals(int n, int keyval, int state,
            struct button buttons[], GtkWidget *gtk_buttons[])
@@ -1352,6 +1543,11 @@ kframe_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
     GtkWidget *focus;
     int retval = FALSE;
 
+    if (check_for_localized_numeric_point(event->keyval) == TRUE) {
+        event->state = 0;
+        event->keyval = GDK_KP_Decimal;
+    }
+
     switch (v->modetype) {
         case BASIC:
             retval = check_vals(B_NOBUTTONS, event->keyval, event->state,
@@ -1527,27 +1723,9 @@ static GtkWidget *
 create_menu(enum menu_type mtype, struct button *n)
 {
     int count = 0;
-    int m;
-    GtkItemFactoryEntry *menu = NULL;
-
-    m = (int) mtype;
+    int m     = (int) mtype;
 
     switch (mtype) {
-        case M_ACC :
-            count = sizeof(acc_menu) / sizeof(acc_menu[0]);
-            menu = &acc_menu[0];
-            break;
-
-        case M_LSHF :
-            count = sizeof(lshift_menu) / sizeof(lshift_menu[0]);
-            menu = &lshift_menu[0];
-            break;
- 
-        case M_RSHF :
-            count = sizeof(rshift_menu) / sizeof(rshift_menu[0]);
-            menu = &rshift_menu[0];
-            break;
- 
         case M_EXCH :
         case M_RCL :
         case M_STO :
@@ -1563,15 +1741,14 @@ create_menu(enum menu_type mtype, struct button *n)
             break;
     }
 
-    if ((mtype == M_ACC || mtype == M_LSHF || mtype == M_RSHF) &&
-        X->menus[m] == NULL) {
-        X->fact[m] = gtk_item_factory_new(GTK_TYPE_MENU, "<popup>", 
-                                          X->kbd_accel);
-	gtk_item_factory_set_translate_func(X->fact[m],
-					    item_factory_translate_func,
-					    NULL, NULL);
-        gtk_item_factory_create_items(X->fact[m], count, menu, (gpointer) m);
-        X->menus[m] = gtk_item_factory_get_widget(X->fact[m], "<popup>");
+    if (X->menus[m] == NULL) {
+        if (mtype == M_ACC) {
+            X->menus[m] = gtk_ui_manager_get_widget(X->ui, "/AccMenu");
+        } else if (mtype == M_LSHF) {
+            X->menus[m] = gtk_ui_manager_get_widget(X->ui, "/LeftShiftMenu");
+        } else if (mtype == M_RSHF) {
+            X->menus[m] = gtk_ui_manager_get_widget(X->ui, "/RightShiftMenu");
+        }
     }
 
     gtk_container_set_border_width(GTK_CONTAINER(X->menus[m]), 1);
@@ -1673,68 +1850,81 @@ make_menu_button(gchar *label_text, int n)
 /* Handle menu bar menu selection. */
 
 static void
-mb_proc(gpointer data, int choice, GtkWidget *item)
+mb_proc(GtkAction *action)
 {
+    const gchar *name = gtk_action_get_name(action);
+    int choice;
+
     if (!v->started) {
         return;
     }
 
-    switch (choice) {
-        case M_QUIT:
-            exit(0);
+    if (EQUAL(name, "Quit")) {
+        exit(0);
+    } else if (EQUAL(name, "Copy")) {
+        get_display();
+    } else if (EQUAL(name, "Paste")) {
+        handle_selection();
+    } else if (EQUAL(name, "Insert")) {
+        show_ascii_frame();
+    } else if (EQUAL(name, "Memory")) {
+        v->rstate = !v->rstate;
+        do_memory(v->rstate);
+    } else if (EQUAL(name, "Contents")) {
+        help_cb();
+    } else if (EQUAL(name, "LSPlaces")) {
+        SSCANF(name,"LSPlaces%d", &choice);
+        choice += (choice < 10) ? '0' : 'A' - 10;
+        handle_menu_selection(X->mrec[(int) M_LSHF], choice);
+    } else if (EQUAL(name, "RSPlaces")) {
+        SSCANF(name,"RSPlaces%d", &choice);
+        choice += (choice < 10) ? '0' : 'A' - 10;
+        handle_menu_selection(X->mrec[(int) M_RSHF], choice);
+    }
+}
 
-        case M_COPY:
-            get_display();
-            break;
 
-        case M_PASTE:
-            handle_selection();
-            break;
+static void 
+mb_base_radio_proc(GtkAction *action, GtkRadioAction *current)
+{
+    const gchar *name = gtk_action_get_name(GTK_ACTION(current));
 
-        case M_ASCII:
-            show_ascii_frame();
-            break;
+    if (!v->started) {
+	return;
+    }
 
-        case M_BASIC:
-            reset_mode_values(BASIC);
-            break;
-
-        case M_FIN:
-            reset_mode_values(FINANCIAL);
-            break;
-
-        case M_SCI:
-            reset_mode_values(SCIENTIFIC);
-            break;
-
-        case M_REGS:
-            v->rstate = !v->rstate;
-            do_memory(v->rstate);
-            break;
-
-        case M_CONTENTS:
-            help_cb();
-            break;
+    if (EQUAL(name, "Basic")) {
+        reset_mode_values(BASIC);
+    } else if (EQUAL(name, "Financial")) {
+        reset_mode_values(FINANCIAL);
+    } else if (EQUAL(name, "Scientific")) {
+        reset_mode_values(SCIENTIFIC);
     }
 }
 
 
 static void
-menu_proc(gpointer data, int choice, GtkWidget *item)
+mb_acc_radio_proc(GtkAction *action, GtkRadioAction *current)
 {
-    handle_menu_selection(X->mrec[(int) data], choice);
+    const gchar *name = gtk_action_get_name(GTK_ACTION(current));
+
+    if (!v->started) {
+	return;
+    }
+
+    handle_menu_selection(X->mrec[(int) M_ACC], name[2]);
 }
 
 
 static void
-mstz_proc(gpointer data, int choice, GtkWidget *item)
+mstz_proc(GtkAction *action)
 {
     GtkWidget *mi;
 
     if (!v->doing_mi) {
 	v->show_zeroes = !v->show_zeroes;
         v->doing_mi = 1;
-        mi = gtk_item_factory_get_widget_by_action(X->fact[(int) M_ACC], 'T');
+        mi = gtk_ui_manager_get_widget(X->ui, "/AccMenu/Show");
         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi), v->show_zeroes);
         v->doing_mi = 0;
 
@@ -1845,20 +2035,25 @@ set_button_state(GtkWidget *w, int isSensitive)
 void
 set_accuracy_toggle(int val)
 {
+    char name[MAXLINE];
     GtkWidget *acc;
 
-    acc = gtk_item_factory_get_widget_by_action(X->fact[(int) M_ACC], 
-                                                val + '0');
+    SPRINTF(name, "/AccMenu/SP%c", val + '0');
+    acc = gtk_ui_manager_get_widget(X->ui, name);
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(acc), TRUE);
 }
 
 
 void
-set_display(char *str)
+set_display(char *str, int minimize_changes)
 {
     char localized[MAX_LOCALIZED];
     GtkTextBuffer *buffer;
     GtkTextIter start, end;
+    gchar *text;
+    gint diff;
+    gint len1, len2;
+    gboolean done;
 
     if (str == NULL || *str == 0) {
         str = " ";
@@ -1868,20 +2063,49 @@ set_display(char *str)
     }
     buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(X->display_item));
     gtk_text_buffer_get_bounds(buffer, &start, &end);
-    gtk_text_buffer_delete(buffer, &start, &end);
+    text = gtk_text_buffer_get_text(buffer, &start, &end, TRUE);
+    diff = strcmp (text, str);
+    if (diff != 0) {
+        len1 = strlen(text);
+        len2 = strlen(str);
 
-    gtk_text_buffer_insert_with_tags_by_name(buffer,
-                                             &end,
-                                             str,
-                                             -1,
-                                             "x-large",
-                                             NULL);
+        done = FALSE;
+        if (minimize_changes) {
+            if (len1 < len2 && strncmp(text, str, len1) == 0) {
+                /* Text insertion */
+                gtk_text_buffer_insert_with_tags_by_name(buffer,
+                                                         &end,
+                                                         str + len1,
+                                                         -1,
+                                                         "x-large",
+                                                         NULL);
+                done = TRUE;
+            } else if (len1 > len2 && strncmp(text, str, len2) == 0) {
+               /* Text deletion */
+                gtk_text_buffer_get_iter_at_offset (buffer, &start, len2);
+                gtk_text_buffer_delete(buffer, &start, &end); 
+                done = TRUE;
+            }
+        }
+             
+ 
+        if (!done) {
+            gtk_text_buffer_delete(buffer, &start, &end);
+
+            gtk_text_buffer_insert_with_tags_by_name(buffer,
+                                                     &end,
+                                                     str,
+                                                     -1,
+                                                     "x-large",
+                                                     NULL);
+        }
+    }
+    g_free (text);
 }
 
 
 #define SET_MENUBAR_ITEM_STATE(i, state) \
-          gtk_widget_set_sensitive( \
-          gtk_item_factory_get_widget_by_action(X->mb_fact, i), state)
+          gtk_widget_set_sensitive(gtk_ui_manager_get_widget(X->ui, i), state)
 
 
 /* When an error condition occurs:
@@ -1922,16 +2146,16 @@ set_error_state(int error)
 
     gtk_widget_set_sensitive(X->mode_panel, !v->error);
 
-    SET_MENUBAR_ITEM_STATE(M_COPY,   !v->error);
-    SET_MENUBAR_ITEM_STATE(M_PASTE,  !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_ASCII,  !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_BASIC,  !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_FIN,    !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_SCI,    !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_ZEROES, !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_TSEP,   !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_REGS,   !v->error); 
-    SET_MENUBAR_ITEM_STATE(M_ABOUT,  !v->error);
+    SET_MENUBAR_ITEM_STATE("/MenuBar/EditMenu/Copy",       !v->error);
+    SET_MENUBAR_ITEM_STATE("/MenuBar/EditMenu/Paste",      !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/EditMenu/Insert",     !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Basic",      !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Financial",  !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Scientific", !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Trailing",   !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Thousands",  !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Memory",     !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/HelpMenu/About",      !v->error);
 }
 
 
@@ -1954,7 +2178,7 @@ set_memory_toggle(int state)
 {
     GtkWidget *reg;
 
-    reg = gtk_item_factory_get_widget_by_action(X->mb_fact, M_REGS);  
+    reg = gtk_ui_manager_get_widget(X->ui, "/MenuBar/ViewMenu/Memory");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(reg), state);
 }
 
@@ -2061,14 +2285,8 @@ set_title(enum fcp_type fcptype, char *str)
 static void
 set_gcalctool_icon(void)
 {    
-    gchar *filename = PACKAGE_PIXMAP_DIR"/gcalctool.png";
-
-    if (g_file_test(filename, G_FILE_TEST_EXISTS) == TRUE) {    
-        X->icon = gdk_pixbuf_new_from_file(filename, NULL);
-    }
-    else {
-        X->icon = NULL;
-    }
+    X->icon = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+                                       "gnome-calculator", 48, 0, NULL);
 }
 
 
@@ -2077,7 +2295,7 @@ set_show_tsep_toggle(int state)
 {
     GtkWidget *mi;
 
-    mi = gtk_item_factory_get_widget_by_action(X->mb_fact, M_TSEP);
+    mi = gtk_ui_manager_get_widget(X->ui, "/MenuBar/ViewMenu/Thousands");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi), state);
 }
 
@@ -2088,10 +2306,10 @@ set_show_zeroes_toggle(int state)
     GtkWidget *mi;
 
     v->doing_mi = 1;    /* Hack to get [a,m]stz_proc() to just return. */
-    mi = gtk_item_factory_get_widget_by_action(X->fact[(int) M_ACC], 'T');
+    mi = gtk_ui_manager_get_widget(X->ui, "/AccMenu/Show");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi), state);
 
-    mi = gtk_item_factory_get_widget_by_action(X->mb_fact, M_ZEROES);
+    mi = gtk_ui_manager_get_widget(X->ui, "/MenuBar/ViewMenu/Trailing");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi), state);
     gtk_widget_set_sensitive(mi, v->modetype == SCIENTIFIC);
     v->doing_mi = 0;
@@ -2133,7 +2351,7 @@ start_tool()
 
 
 static void
-ts_proc(gpointer data, int choice, GtkWidget *item)
+ts_proc(GtkAction *action)
 {
     if (!v->started) {
 	return;
